@@ -8,8 +8,7 @@ use proc_macro2::LineColumn;
 
 use std::fmt;
 
-/// Determine if a `CommentVariant`
-/// is a documentation comment or not.
+/// Determine if a `CommentVariant` is a documentation comment or not.
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum CommentVariantCategory {
     /// Comment variant will end up in documentation.
@@ -18,6 +17,8 @@ pub enum CommentVariantCategory {
     Dev,
     /// It's a common mark file, and we actually don't know.
     CommonMark,
+    /// Toml entries and such.
+    Unmergable,
 }
 
 /// Track what kind of comment the literal is
@@ -37,7 +38,8 @@ pub enum CommentVariant {
     /// `#[doc=` with actual prefix like `#[doc=` and the total length of `r###`
     /// etc. including `r` but without `"`
     MacroDocEqStr(String, usize),
-    /// `#[doc= foo!(..)]`, content will be ignored, but allows clusters to not continue.
+    /// `#[doc= foo!(..)]`, content will be ignored, but allows clusters to not
+    /// continue.
     MacroDocEqMacro,
     /// Commonmark File
     CommonMark,
@@ -47,6 +49,8 @@ pub enum CommentVariant {
     SlashStar,
     /// Unknown Variant
     Unknown,
+    /// Toml entry
+    TomlEntry,
 }
 
 impl Default for CommentVariant {
@@ -66,6 +70,7 @@ impl CommentVariant {
             Self::SlashAsteriskEM => CommentVariantCategory::Doc,
             Self::SlashAsteriskAsterisk => CommentVariantCategory::Doc,
             Self::CommonMark => CommentVariantCategory::CommonMark,
+            Self::TomlEntry => CommentVariantCategory::Unmergable,
             _ => CommentVariantCategory::Dev,
         }
     }
@@ -92,6 +97,7 @@ impl CommentVariant {
             CommentVariant::SlashAsterisk => "/*".to_string(),
             CommentVariant::SlashAsteriskEM => "/*!".to_string(),
             CommentVariant::SlashAsteriskAsterisk => "/**".to_string(),
+            CommentVariant::TomlEntry => "".to_owned(),
             unhandled => unreachable!(
                 "String representation for comment variant {:?} exists. qed",
                 unhandled
@@ -220,9 +226,9 @@ fn trim_span(content: &str, span: &mut Span, pre: usize, post: usize) {
 
 /// Detect the comment variant based on the span based str content.
 ///
-/// Became necessary, since the `proc_macro2::Span` does not distinguish
-/// between `#[doc=".."]` and `/// ..` comment variants, and for one,
-/// and the span can't cover both correctly.
+/// Became necessary, since the `proc_macro2::Span` does not distinguish between
+/// `#[doc=".."]` and `/// ..` comment variants, and for one, and the span can't
+/// cover both correctly.
 fn detect_comment_variant(
     content: &str,
     rendered: &String,
@@ -282,8 +288,9 @@ fn detect_comment_variant(
 
         #[cfg(debug_assertions)]
         {
-            let raw = dbg!(util::load_span_from(&mut content.as_bytes(), orig)?);
-            let adjusted = dbg!(util::load_span_from(&mut content.as_bytes(), span.clone())?);
+            let raw = util::load_span_from(&mut content.as_bytes(), orig)?;
+            let adjusted = util::load_span_from(&mut content.as_bytes(), span.clone())?;
+
             // we know pre and post only consist of single byte characters
             // so `.len()` is way faster here yet correct.
             assert_eq!(adjusted.len() + pre + post, raw.len());
